@@ -2,7 +2,7 @@ package Text::Template::Simple::Constants;
 use strict;
 use vars qw($VERSION $OID $DID @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
 
-$VERSION = '0.62_17';
+$VERSION = '0.62_18';
 
 # object fields
 BEGIN { $OID = -1 } # init object field id counter
@@ -129,32 +129,6 @@ use constant DIGEST_MODS => qw(
 use constant RE_PIPE_SPLIT   => qr/ \| (?:\s+)? (PARAM|FILTER) : /xms;
 use constant RE_FILTER_SPLIT => qr/ \, (?:\s+)? /xms;
 
-use constant FRAGMENT_TMP      => <<'TEMPLATE_CONSTANT';
-
-# BEGIN TIDIED FRAGMENT
-
-%s
-
-# END TIDIED FRAGMENT
-TEMPLATE_CONSTANT
-
-use constant COMPILE_ERROR_TMP => <<'TEMPLATE_CONSTANT';
-Error compiling code fragment (cache id: %s):
-
-%s
--------------------------------
-PARSED CODE (VERBATIM):
--------------------------------
-
-%s
-
--------------------------------
-PARSED CODE    (tidied):
--------------------------------
-
-%s
-TEMPLATE_CONSTANT
-
 use constant DISK_CACHE_COMMENT => <<"TEMPLATE_CONSTANT";
 # !!!   W A R N I N G      W A R N I N G      W A R N I N G   !!!
 # This file is automatically generated by %s on %s.
@@ -232,8 +206,6 @@ BEGIN {
                         PARENT
                      )],
       templates =>   [qw(
-                        COMPILE_ERROR_TMP
-                        FRAGMENT_TMP
                         DISK_CACHE_COMMENT
                         DISK_CACHE_MARKER
                      )],
@@ -368,7 +340,7 @@ TODO
 
 =head1 DESCRIPTION
 
-This document describes version C<0.62_17> of C<Text::Template::Simple::Constants>
+This document describes version C<0.62_18> of C<Text::Template::Simple::Constants>
 released on C<26 April 2009>.
 
 B<WARNING>: This version of the module is part of a
