@@ -33,7 +33,7 @@ package Text::Template::Simple::Constants;
 use strict;
 use vars qw($VERSION $OID $DID @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
 
-$VERSION = '0.62_17';
+$VERSION = '0.62_18';
 
 # object fields
 BEGIN { $OID = -1 } # init object field id counter
@@ -160,32 +160,6 @@ use constant DIGEST_MODS => qw(
 use constant RE_PIPE_SPLIT   => qr/ \| (?:\s+)? (PARAM|FILTER) : /xms;
 use constant RE_FILTER_SPLIT => qr/ \, (?:\s+)? /xms;
 
-use constant FRAGMENT_TMP      => <<'TEMPLATE_CONSTANT';
-
-# BEGIN TIDIED FRAGMENT
-
-%s
-
-# END TIDIED FRAGMENT
-TEMPLATE_CONSTANT
-
-use constant COMPILE_ERROR_TMP => <<'TEMPLATE_CONSTANT';
-Error compiling code fragment (cache id: %s):
-
-%s
--------------------------------
-PARSED CODE (VERBATIM):
--------------------------------
-
-%s
-
--------------------------------
-PARSED CODE    (tidied):
--------------------------------
-
-%s
-TEMPLATE_CONSTANT
-
 use constant DISK_CACHE_COMMENT => <<"TEMPLATE_CONSTANT";
 # !!!   W A R N I N G      W A R N I N G      W A R N I N G   !!!
 # This file is automatically generated by %s on %s.
@@ -263,8 +237,6 @@ BEGIN {
                         PARENT
                      )],
       templates =>   [qw(
-                        COMPILE_ERROR_TMP
-                        FRAGMENT_TMP
                         DISK_CACHE_COMMENT
                         DISK_CACHE_MARKER
                      )],
@@ -391,7 +363,7 @@ use vars qw($VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
 use Text::Template::Simple::Constants qw( :info DIGEST_MODS );
 use Carp qw( croak );
 
-$VERSION = '0.62_17';
+$VERSION = '0.62_18';
 
 BEGIN {
    if ( IS_WINDOWS ) {
@@ -604,7 +576,7 @@ use strict;
 use vars qw($VERSION);
 use Text::Template::Simple::Dummy;
 
-$VERSION = '0.62_17';
+$VERSION = '0.62_18';
 
 sub _compile { shift; return __PACKAGE__->_object->reval(shift) }
 
@@ -637,7 +609,7 @@ use overload q{""} => 'get';
 use Text::Template::Simple::Constants qw( MAX_FL );
 use Text::Template::Simple::Util      qw( DIGEST fatal );
 
-$VERSION = '0.62_17';
+$VERSION = '0.62_18';
 
 my $RE_INVALID = qr{[^A-Za-z_0-9]};
 
@@ -675,11 +647,12 @@ sub _custom {
 package Text::Template::Simple::Base::Parser;
 use strict;
 use vars qw($VERSION);
+
+$VERSION = '0.62_18';
+
 use Text::Template::Simple::Util qw(:all);
 use Text::Template::Simple::Constants qw(:all);
 
-$VERSION = '0.62_17';
-
 # internal code templates
 my %INTERNAL = (
    # we need string eval in this template to catch syntax errors
@@ -753,6 +726,32 @@ my %INTERNAL = (
             } @{ <%BUF%> }
          );
    ),
+
+   compile_error => <<'TEMPLATE_CONSTANT',
+Error compiling code fragment (cache id: <%CID%>):
+
+<%ERROR%>
+-------------------------------
+PARSED CODE (VERBATIM):
+-------------------------------
+
+<%PARSED%>
+
+-------------------------------
+PARSED CODE    (tidied):
+-------------------------------
+
+<%TIDIED%>
+TEMPLATE_CONSTANT
+   fragment => <<'TEMPLATE_CONSTANT',
+
+# BEGIN TIDIED FRAGMENT
+
+<%FRAGMENT%>
+
+# END TIDIED FRAGMENT
+TEMPLATE_CONSTANT
+
 );
 
 sub _internal {
@@ -943,8 +942,11 @@ sub _wrapper {
    # make this a capture sub if we're including
    $wrapper .= '->()' if $inside_inc;
 
-   LOG( COMPILED => sprintf FRAGMENT_TMP, $self->_tidy($wrapper) )
-      if DEBUG() > 1;
+   LOG( COMPILED =>  $self->_mini_compiler(
+                        $self->_internal('fragment'),
+                        { FRAGMENT => $self->_tidy($wrapper) }
+                     )
+   ) if DEBUG > 1;
    #LOG( OUTPUT => $wrapper );
    # reset
    $self->[DEEP_RECURSION] = 0 if $self->[DEEP_RECURSION];
@@ -1065,7 +1067,7 @@ use vars qw($VERSION);
 use Text::Template::Simple::Util qw(:all);
 use Text::Template::Simple::Constants qw(:all);
 
-$VERSION = '0.62_17';
+$VERSION = '0.62_18';
 
 sub _include_no_monolith {
    # no monolith eh?
@@ -1228,7 +1230,7 @@ use vars qw($VERSION);
 use Text::Template::Simple::Util qw(:all);
 use Text::Template::Simple::Constants qw(:all);
 
-$VERSION = '0.62_17';
+$VERSION = '0.62_18';
 
 sub _examine {
    my $self   = shift;
@@ -1295,7 +1297,7 @@ use vars qw($VERSION);
 use Text::Template::Simple::Util qw(:all);
 use Text::Template::Simple::Constants qw(:all);
 
-$VERSION = '0.62_17';
+$VERSION = '0.62_18';
 
 sub _compiler { shift->[SAFE] ? COMPILER_SAFE : COMPILER }
 
@@ -1451,7 +1453,7 @@ package Text::Template::Simple::Tokenizer;
 use strict;
 use vars qw($VERSION);
 
-$VERSION = '0.62_17';
+$VERSION = '0.62_18';
 
 use constant CMD_CHAR             =>  0;
 use constant CMD_ID               =>  1;
@@ -1771,7 +1773,7 @@ use Text::Template::Simple::Util qw( DEBUG LOG ishref binary_mode fatal );
 use constant MY_IO_LAYER      => 0;
 use constant MY_INCLUDE_PATHS => 1;
 
-$VERSION = '0.62_17';
+$VERSION = '0.62_18';
 
 sub new {
    my $class = shift;
@@ -1907,7 +1909,7 @@ use vars qw($VERSION);
 use Text::Template::Simple::Caller;
 use Text::Template::Simple::Util qw();
 
-$VERSION = '0.62_17';
+$VERSION = '0.62_18';
 
 sub stack { # just a wrapper
    my $opt = shift || {};
@@ -1923,7 +1925,7 @@ use strict;
 use vars qw($VERSION);
 use Text::Template::Simple::Dummy;
 
-$VERSION = '0.62_17';
+$VERSION = '0.62_18';
 
 sub _compile { shift; return eval shift }
 
@@ -1942,7 +1944,7 @@ use constant HINTS      => 8;
 use constant BITMASK    => 9;
 use Text::Template::Simple::Util qw( ishref fatal );
 
-$VERSION = '0.62_17';
+$VERSION = '0.62_18';
 
 sub stack {
    my $self    = shift;
@@ -2115,7 +2117,7 @@ use Text::Template::Simple::Constants qw(:all);
 use Text::Template::Simple::Util qw( DEBUG LOG ishref fatal );
 use Carp qw( croak );
 
-$VERSION = '0.62_17';
+$VERSION = '0.62_18';
 
 my $CACHE = {}; # in-memory template cache
 
@@ -2464,7 +2466,12 @@ sub populate {
       my $cid    = $cache_id ? $cache_id : 'N/A';
       my $tidied = $parent->_tidy( $parsed );
       croak $parent->[VERBOSE_ERRORS]
-            ? sprintf(COMPILE_ERROR_TMP, $cid, $error, $parsed, $tidied)
+            ? $parent->_mini_compiler( $parent->_internal('compile_error'), {
+               CID => $cid,
+               ERROR => $error,
+               PARSED => $parsed,
+               TIDIED => $tidied,
+                                                                        } )
             : $error
             ;
    }
@@ -2499,7 +2506,7 @@ package Text::Template::Simple;
 use strict;
 use vars qw($VERSION);
 
-$VERSION = '0.62_17';
+$VERSION = '0.62_18';
 
 use File::Spec;
 use Text::Template::Simple::Constants qw(:all);
@@ -2755,7 +2762,7 @@ generated with an automatic build tool. If you experience problems
 with this version, please install and use the supported standard
 version. This version is B<NOT SUPPORTED>.
 
-This document describes version C<0.62_17> of C<Text::Template::Simple>
+This document describes version C<0.62_18> of C<Text::Template::Simple>
 released on C<26 April 2009>.
 
 B<WARNING>: This version of the module is part of a
@@ -3053,6 +3060,9 @@ actual block content.
 
 =head3 BLOCK FILTERS
 
+B<WARNING> Block filters are considered to be experimental. They may be changed
+or completely removed in the future.
+
 Identical to include filters, but works on blocks of text:
 
    <%| FILTER: HTML, OtherFilter;
